package com.yunfeiyun.agmp.fms.mapper;

import com.yunfeiyun.agmp.fms.domain.WmsWarehouse;
import java.util.List;


/**
 * 仓库Mapper接口
 * 
 * @author 杨晓辉
 * @date 2023-05-25
 */
public interface WmsWarehouseMapper 
{
    /**
     * 查询仓库
     * 
     * @param warehouseId 仓库主键
     * @return 仓库
     */
    public WmsWarehouse selectWmsWarehouseByWarehouseId(String warehouseId);

    /**
     * 查询仓库列表
     * 
     * @param wmsWarehouse 仓库
     * @return 仓库集合
     */
    public List<WmsWarehouse> selectWmsWarehouseList(WmsWarehouse wmsWarehouse);

    /**
     * 新增仓库
     * 
     * @param wmsWarehouse 仓库
     * @return 结果
     */
    public int insertWmsWarehouse(WmsWarehouse wmsWarehouse);

    /**
     * 修改仓库
     * 
     * @param wmsWarehouse 仓库
     * @return 结果
     */
    public int updateWmsWarehouse(WmsWarehouse wmsWarehouse);

    /**
     * 删除仓库
     * 
     * @param warehouseId 仓库主键
     * @return 结果
     */
    public int deleteWmsWarehouseByWarehouseId(String warehouseId);

    /**
     * 批量删除仓库
     * 
     * @param warehouseIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWmsWarehouseByWarehouseIds(String[] warehouseIds);
}
